@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0110';
+our $VERSION = '0.0111';
 
 use strict;
 use warnings;
@@ -30,6 +30,7 @@ sub new {
     $opts{deposit}  ||= '';
     if ($opts{deposit}) {
         ($opts{prefix}, $opts{path}) = fileparse($opts{deposit});
+        die "Invalid path: $opts{path}\n" unless -d $opts{path};
     }
 
     $opts{device} = RtMidiOut->new;
@@ -118,7 +119,7 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0110
+version 0.0111
 
 =head1 SYNOPSIS
 
@@ -203,7 +204,7 @@ Play a given MIDI score in real-time.
 
 =head1 SEE ALSO
 
-Examples can be found in the F<eg/*> files in this distribution.
+Examples are the F<eg/*> files in this distribution.
 
 L<MIDI::RtMidi::FFI::Device>
 
